@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: exceptionhandler.cc,v 1.3 2004/02/10 14:26:04 murrayc Exp $ */
+/* $Id: exceptionhandler.cc,v 1.4.2.1 2006/05/10 13:06:42 murrayc Exp $ */
 
 /* exceptionhandler.cc
  *
@@ -32,6 +32,7 @@
 GLIBMM_USING_STD(exception)
 GLIBMM_USING_STD(list)
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 
 namespace
 {
@@ -40,10 +41,10 @@ typedef sigc::signal<void> HandlerList;
 
 // Each thread has its own list of exception handlers
 // to avoid thread synchronization problems.
-Glib::StaticPrivate<HandlerList> thread_specific_handler_list = GLIBMM_STATIC_PRIVATE_INIT;
+static Glib::StaticPrivate<HandlerList> thread_specific_handler_list = GLIBMM_STATIC_PRIVATE_INIT;
 
 
-void glibmm_exception_warning(const GError* error)
+static void glibmm_exception_warning(const GError* error)
 {
   g_assert(error != 0);
 
@@ -56,7 +57,7 @@ void glibmm_exception_warning(const GError* error)
       (error->message) ? error->message : "(null)");
 }
 
-void glibmm_unexpected_exception()
+static void glibmm_unexpected_exception()
 {
   try
   {
@@ -157,3 +158,6 @@ void exception_handlers_invoke() throw()
 
 } // namespace Glib
 
+#endif //GLIBMM_EXCEPTIONS_ENABLED
+
+
